<?php

namespace Drupal\switch_theme;

use Drupal\Core\Database\Connection;

/**
 * Switch theme manager
 */
class SwitchthemeManager implements SwitchthemeManagerInterface {
  
  /**
   * Database connection
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;
 
  /**
   * @var \Drupal\Core\Database\Connection
   */
  public function __construct(Connection $connection) {
    $this->connection = $connection;
  }
  
  /**
   * Get Switch themes
   * 
   * @return array
   */
  public function getSwitchThemes() {

    $query = $this->connection->select('switch_theme', 's');
    $query->innerJoin('switch_theme_role', 'sr', 's.id = sr.switch_theme_id');
    $query->innerJoin('switch_theme_pattern', 'sp', 's.id = sp.switch_theme_id');
    $query->innerJoin('switch_theme_theme', 'st', 's.id = st.switch_theme_id');
    $query->fields('s', ['id']);
    $query->fields('sp', ['pattern']);
    $query->fields('st', ['theme_code']);
    $query->fields('sr', ['role_code']);

    $results = $query->execute()
      ->fetchAll();
     
    $return = [];
    foreach ($results as $result) {
      $return[] = [
          'pattern'     => $result->pattern,
          'theme_code'  => $result->theme_code,
          'role_code'   => $result->role_code,
      ];
    }

    return $return;  
  }

  /**
   * Get item
   * 
   * @param int Switch theme id $id
   *
   * @return \stdClass|null
   */
  public function getItem($id) {

    $query = $this->connection->select('switch_theme', 's');
    $query->fields('s', ['name']);
    $query->innerJoin('switch_theme_pattern', 'sp', 's.id = sp.switch_theme_id');
    $query->innerJoin('switch_theme_theme', 'st', 's.id = st.switch_theme_id'); 
    $query->fields('sp', ['pattern']);
    $query->fields('st', ['theme_code']);
    $query->condition('s.id', (int) $id, "=");
    return $query->execute()
        ->fetchObject();
  }

  /**
   * Get selected roles
   *
   * @param int Switch theme id $id
   * 
   * @return array
   */
  public function getSelectedRole($id) {

      return $this->connection->select('switch_theme_role')
          ->fields('switch_theme_role', ['role_code'])
          ->condition('switch_theme_id', (int) $id, "=")
          ->execute()
          ->fetchObject();
  }
}
